/*
 *
 * Copyright (c) 1998 Scott Oaks. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and
 * without fee is hereby granted.
 *
 * This sample source code is provided for example only,
 * on an unsupported, as-is basis. 
 *
 * AUTHOR MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. AUTHOR SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * THIS SOFTWARE IS NOT DESIGNED OR INTENDED FOR USE OR RESALE AS ON-LINE
 * CONTROL EQUIPMENT IN HAZARDOUS ENVIRONMENTS REQUIRING FAIL-SAFE
 * PERFORMANCE, SUCH AS IN THE OPERATION OF NUCLEAR FACILITIES, AIRCRAFT
 * NAVIGATION OR COMMUNICATION SYSTEMS, AIR TRAFFIC CONTROL, DIRECT LIFE
 * SUPPORT MACHINES, OR WEAPONS SYSTEMS, IN WHICH THE FAILURE OF THE
 * SOFTWARE COULD LEAD DIRECTLY TO DEATH, PERSONAL INJURY, OR SEVERE
 * PHYSICAL OR ENVIRONMENTAL DAMAGE ("HIGH RISK ACTIVITIES").  AUTHOR
 * SPECIFICALLY DISCLAIMS ANY EXPRESS OR IMPLIED WARRANTY OF FITNESS FOR
 * HIGH RISK ACTIVITIES.
 */


import java.io.*;
import java.security.*;
import java.util.*;

public class XYZIdentityScope extends IdentityScope {
	private transient IdentityScope publicScope;
	private transient IdentityScope privateScope;

	public XYZIdentityScope() throws KeyManagementException {
		super("XYZIdentityScope");
		privateScope = new XYZFileScope("/floppy/floppy0/private");
		publicScope = new XYZFileScope("/auto/shared/sharedScope");
		setSystemScope(this);
	}
	
	public int size() {
		return publicScope.size() + privateScope.size();
	}

	public Identity getIdentity(String name) {
		Identity id;
		id = privateScope.getIdentity(name);
		if (id == null)
			id = publicScope.getIdentity(name);
		return id;
	}

	public Identity getIdentity(PublicKey key) {
		Identity id;
		id = privateScope.getIdentity(key);
		if (id == null)
			id = publicScope.getIdentity(key);
		return id;
	}

	public void addIdentity(Identity identity) throws KeyManagementException {
		throw new KeyManagementException("This scope does not support adding identities");
	}

	public void removeIdentity(Identity identity) throws KeyManagementException {
		throw new KeyManagementException("This scope does not support removing identities");
	}

	class XYZIdentityScopeEnumerator implements Enumeration {
		private boolean donePrivate = false;
		Enumeration pubEnum = null, privEnum = null;

		XYZIdentityScopeEnumerator() {
			pubEnum = publicScope.identities();
			privEnum = privateScope.identities();
			if (!privEnum.hasMoreElements())
				donePrivate = true;
		}

		public boolean hasMoreElements() {
			return pubEnum.hasMoreElements() || privEnum.hasMoreElements();
		}

		public Object nextElement() {
			Object o = null;
			if (!donePrivate) {
				o = privEnum.nextElement();
				if (!privEnum.hasMoreElements())
					donePrivate = true;
			}
			else o = pubEnum.nextElement();
			if (o == null)
				throw new NoSuchElementException("XYZIdentityScopeEnumerator");
			return o;
		}
	}

	public Enumeration identities() {
		return new XYZIdentityScopeEnumerator();
	}
}
