/*
 *
 * Copyright (c) 1998 Scott Oaks. All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software
 * and its documentation for NON-COMMERCIAL purposes and
 * without fee is hereby granted.
 *
 * This sample source code is provided for example only,
 * on an unsupported, as-is basis. 
 *
 * AUTHOR MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
 * TO THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NON-INFRINGEMENT. AUTHOR SHALL NOT BE LIABLE FOR
 * ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR
 * DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
 *
 * THIS SOFTWARE IS NOT DESIGNED OR INTENDED FOR USE OR RESALE AS ON-LINE
 * CONTROL EQUIPMENT IN HAZARDOUS ENVIRONMENTS REQUIRING FAIL-SAFE
 * PERFORMANCE, SUCH AS IN THE OPERATION OF NUCLEAR FACILITIES, AIRCRAFT
 * NAVIGATION OR COMMUNICATION SYSTEMS, AIR TRAFFIC CONTROL, DIRECT LIFE
 * SUPPORT MACHINES, OR WEAPONS SYSTEMS, IN WHICH THE FAILURE OF THE
 * SOFTWARE COULD LEAD DIRECTLY TO DEATH, PERSONAL INJURY, OR SEVERE
 * PHYSICAL OR ENVIRONMENTAL DAMAGE ("HIGH RISK ACTIVITIES").  AUTHOR
 * SPECIFICALLY DISCLAIMS ANY EXPRESS OR IMPLIED WARRANTY OF FITNESS FOR
 * HIGH RISK ACTIVITIES.
 */


import java.security.KeyStore;
import java.security.PublicKey;
import java.security.PrivateKey;
import java.security.cert.*;
import java.io.*;

public class KeyStoreLookup {
	public static void main(String args[]) {
		try {
			KeyStore ks = KeyStore.getInstance();
			String fname = System.getProperty("user.home") +
								File.separator + ".keystore";
			FileInputStream fis = new FileInputStream(fname);
			ks.load(fis, null);
			if (ks.isKeyEntry(args[0])) {
				System.out.println(args[0] +
								" is a key entry in the keystore");
				System.out.println("The private key for " + args[0] +
						 " is " + ks.getPrivateKey(args[0], args[1]));
				Certificate certs[] = ks.getCertificateChain(args[0]);
				if (certs[0] instanceof X509Certificate) {
					X509Certificate x509 = (X509Certificate) certs[0];
					System.out.println(args[0] + " is really " +
						x509.getSubjectDN());
				}
				if (certs[certs.length - 1] instanceof
									 X509Certificate) {
					X509Certificate x509 = (X509Certificate) 
										certs[certs.length - 1];
					System.out.println(args[0] + " was verified by " +
						x509.getIssuerDN());
				}
			}
			else if (ks.isCertificateEntry(args[0])) {
				System.out.println(args[0] +
							" is a certificate entry in the keystore");
				Certificate c = ks.getCertificate(args[0]);
				if (c instanceof X509Certificate) {
					X509Certificate x509 = (X509Certificate) c;
					System.out.println(args[0] + " is really " +
						x509.getSubjectDN());
					System.out.println(args[0] + " was verified by " +
						x509.getIssuerDN());
				}
			}
			else {
				System.out.println(args[0] +
						" is unknown to this keystore");
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}
